@@ -8,8 +8,7 @@ from collective.geo.geographer.interfaces import IWriteGeoreferenced
 
 
 class GeoManager(object):
-    """
-      We instanciate a GeoManager on a non georeferenceable context
+    """We instanciate a GeoManager on a non georeferenceable context
       >>> geo = GeoManager(None)
       >>> geo.isGeoreferenceable()
       False
@@ -60,11 +59,25 @@ class GeoManager(object):
       True
 
       We can also change the coordinates to represent a Polygon
-      >>> geo.setCoordinates('Polygon', (((0.111,0.222),(0.222,0.222), (0.222,0.111),(0.111,0.111)),) )
+      >>> poligon_coords = (((0.111,0.222),(0.222,0.222),
+      ...    (0.222,0.111),(0.111,0.111)),)
+
+      >>> geo.setCoordinates('Polygon', poligon_coords)
 
       and get its coordinates back accordingly
+      >>> coords = geo.getCoordinates()
+      >>> coords[0]
+      'Polygon'
+      >>> coords[1] == poligon_coords
+      True
+
+      To remove coordinates from an object we can
+      call removeCoordinates method
+
+      >>> geo.removeCoordinates()
       >>> geo.getCoordinates()
-      ('Polygon', (((0.111, 0.222), (0.222, 0.222), (0.222, 0.111), (0.111, 0.111)),))
+      (None, None)
+
 
     """
     interface.implements(IGeoManager)
@@ -97,7 +110,7 @@ class GeoManager(object):
             pass
         return u''
 
-    def __init__(self, context, form = None):
+    def __init__(self, context, form=None):
         self.context = context
         self.form = form
 
@@ -115,3 +128,8 @@ class GeoManager(object):
         if(self.isGeoreferenceable()):
             geo = IWriteGeoreferenced(self.context)
             geo.setGeoInterface(type, coords)
+
+    def removeCoordinates(self):
+        if(self.isGeoreferenceable()):
+            geo = IWriteGeoreferenced(self.context)
+            geo.removeGeoInterface()
